summaryrefslogtreecommitdiff
path: root/scripts/fuzz_opt.py
diff options
context:
space:
mode:
authorAshley Nelson <nashley@google.com>2023-08-21 19:29:10 -0700
committerGitHub <noreply@github.com>2023-08-21 19:29:10 -0700
commitafca5f51a46750927ac9263297d24b224915e558 (patch)
treeb8ac65ee40ca41668d111bb8545a7797b165671a /scripts/fuzz_opt.py
parent905e2fc25208c0bce3f78ac4ac3315219194e768 (diff)
downloadbinaryen-afca5f51a46750927ac9263297d24b224915e558.tar.gz
binaryen-afca5f51a46750927ac9263297d24b224915e558.tar.bz2
binaryen-afca5f51a46750927ac9263297d24b224915e558.zip
Rename multimemory flag (#5890)
Renaming the multimemory flag in Binaryen to match its naming in LLVM.
Diffstat (limited to 'scripts/fuzz_opt.py')
-rwxr-xr-xscripts/fuzz_opt.py8
1 files changed, 4 insertions, 4 deletions
diff --git a/scripts/fuzz_opt.py b/scripts/fuzz_opt.py
index b468755ff..7f9dd91d0 100755
--- a/scripts/fuzz_opt.py
+++ b/scripts/fuzz_opt.py
@@ -306,7 +306,7 @@ INITIAL_CONTENTS_IGNORE = [
'fib2_emptylocspan_dwarf.wasm',
'fannkuch3_dwarf.wasm',
'multi_unit_abbrev_noprint.wasm',
# TODO fuzzer support for multi-memories
'multi-memories-atomics64.wast',
'multi-memories-basics.wast',
'multi-memories-simd.wast',
@@ -918,7 +918,7 @@ class CompareVMs(TestCaseHandler):
compare(before[vm], after[vm], 'CompareVMs between before and after: ' + vm.name)
def can_run_on_feature_opts(self, feature_opts):
- return all_disallowed(['simd', 'multivalue', 'multi-memories'])
+ return all_disallowed(['simd', 'multivalue', 'multimemory'])
# Check for determinism - the same command must have the same output.
@@ -1062,7 +1062,7 @@ class Wasm2JS(TestCaseHandler):
# specifically for growth here
if INITIAL_CONTENTS:
return False
- return all_disallowed(['exception-handling', 'simd', 'threads', 'bulk-memory', 'nontrapping-float-to-int', 'tail-call', 'sign-ext', 'reference-types', 'multivalue', 'gc', 'multi-memories'])
+ return all_disallowed(['exception-handling', 'simd', 'threads', 'bulk-memory', 'nontrapping-float-to-int', 'tail-call', 'sign-ext', 'reference-types', 'multivalue', 'gc', 'multimemory'])
class Asyncify(TestCaseHandler):
@@ -1132,7 +1132,7 @@ class Asyncify(TestCaseHandler):
compare(before, after_asyncify, 'Asyncify (before/after_asyncify)')
def can_run_on_feature_opts(self, feature_opts):
- return all_disallowed(['exception-handling', 'simd', 'tail-call', 'reference-types', 'multivalue', 'gc', 'multi-memories'])
+ return all_disallowed(['exception-handling', 'simd', 'tail-call', 'reference-types', 'multivalue', 'gc', 'multimemory'])
# given a wasm and a list of exports we want to keep, remove all other exports.
@@ -306,7 +306,7 @@ INITIAL_CONTENTS_IGNORE = [
'fannkuch3_dwarf.wasm',
'multi_unit_abbrev_noprint.wasm',
- # TODO fuzzer support for multi-memories
+ # TODO fuzzer support for multimemory
'multi-memories-atomics64.wast',
'multi-memories-basics.wast',